==> nextcloud-12.0.3-3-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/serverinfo/l10n/fi.js <==
OC.L10N.register(
    "serverinfo",
    {
    "Load average" : "Keskiarvoinen kuorma",
    "Last minute" : "Viimeisin minuutti",
    "Memory info not available" : "Muistin tila ei saatavilla",
    "Total" : "Yhteensä",
    "Current usage" : "Tämänhetkinen kulutus",
    "Users" : "Käyttäjät",
    "Groups" : "Ryhmät",
    "Links" : "Linkit",
    "Federated sent" : "Lähetetty federoituna",
    "Federated received" : "Vastaanotettu federoituna",
    "Last 24 hours" : "Viimeiset 24 tuntia",
    "Last 1 hour" : "Viimeisin tunti",
    "Last 5 mins" : "Viimeiset 5 min",
    "Monitoring" : "Valvonta",
    "CPU load" : "CPU kuorma",
    "Memory usage" : "Muistin käyttö",
    "Active users" : "Aktiiviset käyttäjät",
    "Shares" : "Jaot",
    "Storage" : "Tallennustila",
    "Users:" : "Käyttäjiä:",
    "Files:" : "Tiedostoja:",
    "PHP" : "PHP",
    "Version:" : "Versio:",
    "Memory Limit:" : "Muistin raja:",
    "Max Execution Time:" : "Suurin suoritusaika:",
    "Upload max size:" : "Suurin lähetyksen koko:",
    "Database" : "Tietokanta",
    "Type:" : "Tyyppi:",
    "Size:" : "Koko:",
    "External monitoring tool" : "Ulkopuolinen valvontatyökalu",
    "You can connect an external monitoring tool by using this end point: " : "Voit yhdistää ulkopuolisen valvontatyökalun käyttämällä tätä liityntäkohtaa: ",
    "Server info" : "Palvelimen tiedot",
    "You can connect a external monitoring tool by using this end point: " : "Voit yhdistää ulkopuolisen valvontatyökalun käyttämällä tätä liityntäkohtaa: "
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-13.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/serverinfo/l10n/fi.js <==
OC.L10N.register(
    "serverinfo",
    {
    "Load average" : "Keskiarvoinen kuorma",
    "Last minute" : "Viimeisin minuutti",
    "Memory info not available" : "Muistin tila ei saatavilla",
    "Total" : "Yhteensä",
    "Current usage" : "Tämänhetkinen kulutus",
    "Users" : "Käyttäjät",
    "Groups" : "Ryhmät",
    "Links" : "Linkit",
    "Federated sent" : "Lähetetty federoituna",
    "Federated received" : "Vastaanotettu federoituna",
    "Last 24 hours" : "Viimeiset 24 tuntia",
    "Last 1 hour" : "Viimeisin tunti",
    "Last 5 mins" : "Viimeiset 5 min",
    "Monitoring" : "Valvonta",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Näyttää hyödyllisiä tietoja palvelimesta, kuten suorittimen kuorman, muistin ja levytilan käytön, käyttäjien määrän jne.",
    "CPU load" : "Suorittimen kuorma",
    "Memory usage" : "Muistin käyttö",
    "Active users" : "Aktiiviset käyttäjät",
    "Shares" : "Jaot",
    "Storage" : "Tallennustila",
    "Users:" : "Käyttäjiä:",
    "Files:" : "Tiedostoja:",
    "PHP" : "PHP",
    "Version:" : "Versio:",
    "Memory Limit:" : "Muistin raja:",
    "Max Execution Time:" : "Suurin suoritusaika:",
    "Upload max size:" : "Suurin lähetyksen koko:",
    "Database" : "Tietokanta",
    "Type:" : "Tyyppi:",
    "Size:" : "Koko:",
    "External monitoring tool" : "Ulkopuolinen valvontatyökalu",
    "You can connect an external monitoring tool by using this end point: " : "Voit yhdistää ulkopuolisen valvontatyökalun käyttämällä tätä liityntäkohtaa: "
},
"nplurals=2; plural=(n != 1);");
